@@ -198,7 +198,7 @@ class CInert:
             data=self.__analysis
         else:
             data=analysis
-        t0 = time.clock()
+        t0 = time.time()
         uns_snap=data.uns_snap # link to UNS object
 
         ok,self.__time=uns_snap.unsin.getData("time")
@@ -228,7 +228,7 @@ class CInert:
                 print("2:",pos,ok)
 
             # compute density
-            t00=time.clock()
+            t00=time.time()
             if self.__tree_density:
                 ctree=CTree(pos,None,mass)  # instantiate a ctree object
 
@@ -240,7 +240,7 @@ class CInert:
                 ok,rho,hsml=c.getDensity(pos,mass) # compute density
                 pos=pos
                 mass=mass
-            print("Computing density : %.02f"%(time.clock()-t00),file=sys.stderr)
+            print("Computing density : %.02f"%(time.time()-t00),file=sys.stderr)
 
             #embed()
 
