@@ -4,10 +4,10 @@ from ..uns_simu import *
 from .csnapshot import *
 from .c2dpgplot import *
 import sys
-try:
-    import py_unstools # rectify swig
-except ImportError:
-    print("WARNING !!!,cmovie  failed to import module [py_unstools]",file=sys.stderr)
+#try:
+#    import py_unstools # rectify swig
+#except ImportError:
+#    print("WARNING !!!,cmovie  failed to import module [py_unstools]",file=sys.stderr)
 
 
 import subprocess
@@ -442,8 +442,8 @@ class CMovie:
             ncores=cpu_count()
         if self.__vdebug:
             print ("#cores used :",ncores)
-
-        sql3 = UnsSimu()
+            print ("simname :",simname)
+        sql3 = UnsSimu(simname,verbose=self.__verbose)
         r = sql3.getInfo(simname)
         if (r) : # simulation exist
             dir_movie=r['dir']+'/ANALYSIS/movie'   # movie directory
@@ -511,7 +511,8 @@ def process(args):
         movie.buildMovie(args.simname,args.overwrite,args.ncores)
         pass
     except Exception as x :
-        print(x.message)
+        #print(x.message)
+        print(x)
         sys.exit()
 
 
